@@ -9,7 +9,7 @@ extends q(Data::Validation::Constraints);
 
 EXCEPTION_CLASS->add_exception( 'ValidPassword', {
    parents => [ 'InvalidParameter' ],
-   error   => 'Parameter [_1] value [_2] is not a valid password' } );
+   error   => 'Parameter [_1] is not a valid password' } );
 
 sub validate {
    my ($self, $val) = @_; my $min_length = $self->min_length || 6;
